pub struct BrowserManager { /* private fields */ }Implementations
Sourceimpl BrowserManager
impl BrowserManager
pub async fn new(config: &ChaserConfig) -> ChaserResult<Self>
pub fn is_healthy(&self) -> bool
pub fn active_contexts(&self) -> usize
pub fn max_contexts(&self) -> usize
pub async fn acquire_permit(&self) -> ChaserResult<ContextPermit>
pub fn try_acquire_permit(&self) -> Option<ContextPermit>
pub async fn create_context( &self, proxy: Option<&ProxyConfig>, ) -> ChaserResult<Option<BrowserContextId>>
Sourcepub async fn new_page(
&self,
ctx_id: Option<BrowserContextId>,
url: &str,
) -> ChaserResult<(Page, ChaserPage)>
pub async fn new_page( &self, ctx_id: Option<BrowserContextId>, url: &str, ) -> ChaserResult<(Page, ChaserPage)>
Open a blank page, apply the native profile (OS + real Chrome version), then
navigate to url. Proxy auth is handled by the caller before navigation.
pub async fn shutdown(self)